@@ -57,27 +57,31 @@ def make(package: List[str], install: bool = False, editable: bool = False, forc
             f"Passing unknown packages: {make_packages.difference(packages.keys())}. Available options: {list(packages.keys())}"
         )
 
-    visited_pkgs = {}
+    # mapping from package name to whether the content has been changed since the last built
+    built_pkgs = {}
+    updated_version_pkgs = set()
     for pkg_name in make_packages:
         pkg = packages[pkg_name]
         if install:
+            logger.debug("Install {} external dependencies", pkg_name)
             pkg.install(without_inter_dependency=True)
 
         dep_pkgs = pkg.all_inter_dependencies()
+        update_versions(set(dep_pkgs.keys()).difference(updated_version_pkgs), packages)
+        updated_version_pkgs = updated_version_pkgs.union(dep_pkgs.keys())
+
         for dep_name in topological_sort(dep_pkgs):
-            if dep_name not in visited_pkgs:
+            if dep_name not in built_pkgs:
                 # TODO: optimize this code as we don't need to rebuild if we are install in editable mode
-                visited_pkgs[dep_name] = dep_pkgs[dep_name].build(pbt_cfg)
-                if visited_pkgs[dep_name] and dep_name in pkg.dependencies:
+                built_pkgs[dep_name] = dep_pkgs[dep_name].build(pbt_cfg)
+                if built_pkgs[dep_name] and dep_name in pkg.dependencies:
                     # update if there is a change in the dependency make it no longer compatible,
                     if not pkg.is_package_compatible(dep_pkgs[dep_name]):
                         pkg.update_package_version(dep_pkgs[dep_name])
-            if visited_pkgs[dep_name] or force:
+            if built_pkgs[dep_name] or force:
                 pkg.install_dep(
                     dep_pkgs[dep_name], pbt_cfg, editable=editable, no_build=True
                 )
-
-    update_versions(list(visited_pkgs.keys()), packages)
     return
 
 
