@@ -97,6 +97,9 @@ class Package:
             "Current package {}: install dependency {}", self.name, package.name
         )
         pipfile = self.pkg_handler.pip_path
+        # need to remove the `.egg-info` folders first as it will interfere with the version (ContextualVersionConflict)
+        for eggdir in glob(str(self.dir / "*.egg-info")):
+            shutil.rmtree(eggdir)
         subprocess.check_output([pipfile, "uninstall", "-y", package.name])
 
         if editable:
@@ -106,12 +109,17 @@ class Package:
                     f.write(g.extractfile(member).read())
             rename = (package.dir / "pyproject.toml").exists()
             if rename:
-                os.rename(package.dir / "pyproject.toml", package.dir / "pyproject.toml.tmp")
+                os.rename(
+                    package.dir / "pyproject.toml", package.dir / "pyproject.toml.tmp"
+                )
             try:
-                subprocess.check_call([pipfile, "install", "-e", "."], cwd=package.dir)
+                subprocess.check_output([pipfile, "install", "-e", "."], cwd=package.dir)
             finally:
                 if rename:
-                    os.rename(package.dir / "pyproject.toml.tmp", package.dir / "pyproject.toml")
+                    os.rename(
+                        package.dir / "pyproject.toml.tmp",
+                        package.dir / "pyproject.toml",
+                    )
                 os.remove(package.dir / "setup.py")
         else:
             subprocess.check_output([pipfile, "install", package.get_wheel_file()])
@@ -184,6 +192,9 @@ class Package:
                 patterns.append(pattern)
             else:
                 dir_paths.append(pattern)
+        
+        for depfile in ["pyproject.toml", "requirements.txt"]:
+            dir_paths.append(str(self.dir / depfile))
 
         if len(patterns) > 0:
             raise NotImplementedError()
@@ -245,8 +256,22 @@ def search_packages(pbt_cfg: PBTConfig) -> Dict[str, Package]:
         pkgs[pkg.name] = pkg
 
     pkg_names = set(pkgs.keys())
+    pkg_similar_names = {pkgname.replace("-", "_") for pkgname in pkg_names}
+
     for pkg in pkgs.values():
-        for pname in pkg_names.intersection(pkg.dependencies.keys()):
+        inter_deps = pkg_names.intersection(pkg.dependencies.keys())
+
+        # check for inconsistent naming '-', '_'
+        sim_inter_deps = pkg_similar_names.intersection(
+            (pkgname.replace("-", "_") for pkgname in pkg.dependencies.keys())
+        )
+        if len(inter_deps) != len(sim_inter_deps):
+            invalid_pkg_names = sim_inter_deps.difference(
+                [name.replace("-", "_") for name in inter_deps]
+            )
+            raise Exception(f"Packages {invalid_pkg_names} use inconsistent name")
+
+        for pname in inter_deps:
             pkg.inter_dependencies.append(pkgs[pname])
             pkgs[pname].invert_inter_dependencies.append(pkg)
     for pkg in pkgs.values():
