@@ -75,9 +75,9 @@ class Poetry:
             with self.temporary_mask(
                 [dep_pkg.name for dep_pkg in self.package.inter_dependencies]
             ):
-                subprocess.check_call(["poetry", "install"], cwd=self.package.dir)
+                subprocess.check_output(["poetry", "install"], cwd=self.package.dir)
         else:
-            subprocess.check_call(["poetry", "install"], cwd=self.package.dir)
+            subprocess.check_output(["poetry", "install"], cwd=self.package.dir)
 
     def publish(self):
         subprocess.check_output(["poetry", "publish", "--build"], cwd=self.package.dir)
@@ -126,7 +126,15 @@ class Poetry:
             patch=int(m.group("patch") or "0"),
         )
         if m.group("op") == "^":
-            upperbound = lowerbound.bump_major()
+            # special case for 0 following the nodejs way (I can't believe why)
+            # see more: https://nodesource.com/blog/semver-tilde-and-caret/
+            if lowerbound.major == 0:
+                if lowerbound.minor == 0:
+                    upperbound = lowerbound.bump_patch()
+                else:
+                    upperbound = lowerbound.bump_minor()
+            else:
+                upperbound = lowerbound.bump_major()
         elif m.group("op") == "~":
             if m.group("patch") is not None:
                 upperbound = lowerbound.bump_minor()
